==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Select/SelectLayerByEntity/ts/SelectLayerByEntity_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>SelectLayer</name>
    <message>
        <source>Choose entity on layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wybierz jednostkę na warstwie</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tryb:</translation>
    </message>
    <message>
        <source>Replace the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zamień bieżące zaznaczenie</translation>
    </message>
    <message>
        <source>SelectionMode</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">SelectionMode</translation>
    </message>
    <message>
        <source>Add to the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dodać do wyboru bieżących</translation>
    </message>
    <message>
        <source>Subtract from the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Odejmij od bieżącego zaznaczenia</translation>
    </message>
    <message>
        <source>Intersect with the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Przecięcie z bieżącego zaznaczenia</translation>
    </message>
    <message>
        <source>(De-)Select La&amp;yer</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
(Za/Od)znacz wa&amp;rstwy</translatorcomment>
        <translation type="obsolete">(Za/Od)znacz wa&amp;rstwy</translation>
    </message>
    <message>
        <source>(De-)Select all entities on the same layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">(De-) wybrać wszystkie elementy tej samej warstwy</translation>
    </message>
</context>
<context>
    <name>SelectLayerByEntity</name>
    <message>
        <location filename="../SelectLayerByEntity.js" line="+68"/>
        <source>Choose entity on layer</source>
        <translation type="unfinished">Wybierz jednostkę na warstwie</translation>
    </message>
    <message>
        <location filename="../SelectLayerByEntity.ui" line="+17"/>
        <source>Mode:</source>
        <translation type="unfinished">Tryb:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Replace the current selection</source>
        <translation type="unfinished">Zamień bieżące zaznaczenie</translation>
    </message>
    <message>
        <location line="+16"/>
        <location line="+20"/>
        <location line="+20"/>
        <location line="+20"/>
        <source>SelectionMode</source>
        <translation type="unfinished">SelectionMode</translation>
    </message>
    <message>
        <location line="-53"/>
        <source>Add to the current selection</source>
        <translation type="unfinished">Dodać do wyboru bieżących</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Subtract from the current selection</source>
        <translation type="unfinished">Odejmij od bieżącego zaznaczenia</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Intersect with the current selection</source>
        <translation type="unfinished">Przecięcie z bieżącego zaznaczenia</translation>
    </message>
    <message>
        <location filename="../SelectLayerByEntityInit.js" line="+2"/>
        <source>(De-)Select La&amp;yer</source>
        <translation type="unfinished">(Za/Od)znacz wa&amp;rstwy</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>(De-)Select all entities on the same layer</source>
        <translation type="unfinished">(De-) wybrać wszystkie elementy tej samej warstwy</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Select/SelectLayerByEntity/ts/SelectLayerByEntity_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SelectLayer</name>
    <message>
        <source>Choose entity on layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wybierz jednostkę na warstwie</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tryb:</translation>
    </message>
    <message>
        <source>Replace the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zamień bieżące zaznaczenie</translation>
    </message>
    <message>
        <source>SelectionMode</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">SelectionMode</translation>
    </message>
    <message>
        <source>Add to the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dodać do wyboru bieżących</translation>
    </message>
    <message>
        <source>Subtract from the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Odejmij od bieżącego zaznaczenia</translation>
    </message>
    <message>
        <source>Intersect with the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Przecięcie z bieżącego zaznaczenia</translation>
    </message>
    <message>
        <source>(De-)Select La&amp;yer</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
(Za/Od)znacz wa&amp;rstwy</translatorcomment>
        <translation type="obsolete">(Za/Od)znacz wa&amp;rstwy</translation>
    </message>
    <message>
        <source>(De-)Select all entities on the same layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">(De-) wybrać wszystkie elementy tej samej warstwy</translation>
    </message>
</context>
<context>
    <name>SelectLayerByEntity</name>
    <message>
        <location filename="../SelectLayerByEntity.js" line="+68"/>
        <source>Choose entity on layer</source>
        <translation>Proszę wskazać obiekt na warstwie</translation>
    </message>
    <message>
        <location filename="../SelectLayerByEntity.ui" line="+17"/>
        <source>Mode:</source>
        <translation>Tryb:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Replace the current selection</source>
        <translation>Zamień aktualne zaznaczenie</translation>
    </message>
    <message>
        <location line="+16"/>
        <location line="+20"/>
        <location line="+20"/>
        <location line="+20"/>
        <source>SelectionMode</source>
        <translation>TrybZaznaczania</translation>
    </message>
    <message>
        <location line="-53"/>
        <source>Add to the current selection</source>
        <translation>Dodaj do aktualnego zaznaczenia</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Subtract from the current selection</source>
        <translation>Odejmij od aktualnego zaznaczenia</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Intersect with the current selection</source>
        <translation>Wyznacz część wspólną z aktualnym zaznaczeniem</translation>
    </message>
    <message>
        <location filename="../SelectLayerByEntityInit.js" line="+2"/>
        <source>(De-)Select La&amp;yer</source>
        <translation>Zaznacz &amp;warstwę</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>(De-)Select all entities on the same layer</source>
        <translation>Zaznacza lub odznacza wszystkie obiekty na tej samej warstwie</translation>
    </message>
</context>
</TS>
